@@ -1,18 +1,22 @@
 #!/usr/bin/perl
 
+# This is an example of using Text::Layout to create the same document
+# as native Pango.
+#
+# This example uses Text::Layout in Pango compliance mode. The
+# relevant parts of this program and its Pango counterpart are very
+# much the same.
+
 use strict;
 use warnings;
 use utf8;
 
-use lib "../CPAN";
-use PDF::API2;
-
 use lib "../lib";
+use PDF::API2;
 use Text::Layout;
-use Text::Layout::FontConfig;
 
 # Create document and graphics environment.
-my $pdf = PDF::API2->new();
+my $pdf = PDF::API2->new( file => 'pdfapi1.pdf' );
 $pdf->mediabox( 595, 842 );	# A4
 
 # Set up page and get the text context.
@@ -22,19 +26,29 @@ my $text = $page->text;
 # Create a layout instance.
 my $layout = Text::Layout->new($pdf);
 
-my $PANGO_SCALE;
+# Tell Text::Layout that we are running in Pango compatibility.
+my $PANGO_SCALE = $layout->set_pango_mode("on");
+
+# Scale from Cairo (PDF) font size to Pango.
+my $PANGO_FONT_SCALE = 0.75 * $PANGO_SCALE;
+
+# Font sizes used, scaled.
+my $realfontsize = 60;
+my $fontsize = $realfontsize * $PANGO_FONT_SCALE;
+my $tinysize = 20 * $PANGO_FONT_SCALE;
 
 sub main {
     # Select a font.
-    my $font = Text::Layout::FontConfig->from_string("Serif 60");
+    my $font = Text::Layout::FontConfig->from_string("freeserif 12");
+    $font->set_size($fontsize);
     $layout->set_font_description($font);
 
     # Start...
     my $x = 0;
-    my $y = 500;
+    my $y = 500;		# PDF goes up
 
     # Text to render.
-    $layout->set_markup( q{Áhe <i><span foreground="red">quick</span> <span size="20"><b>brown</b></span></i> fox} );
+    $layout->set_markup( qq{Áhe <i><span foreground="red">quick</span> <span size="$tinysize"><b>brown</b></span></i> fox} );
 
     # Left align text.
     $layout->set_width( 595 * $PANGO_SCALE );
@@ -54,15 +68,13 @@ sub main {
 
     $y -= 100;
 
-    $text->font( $font->{font}, 60);
+    # Plain PDF::API2, no Text::Layout.
+    $text->font( $font->{font}, $realfontsize );
     $text->translate( $x, $y-50 );
     $text->text(q{Áhe quick brown fox});
 
     $y -= 100;
 
-    # Text to render.
-#    $layout->set_markup( q{Áhe quick brown fox} );
-
     # Right align text.
     $layout->set_width( 595 * $PANGO_SCALE );
     $layout->set_alignment("center");
@@ -71,7 +83,7 @@ sub main {
     showlayout( $x, $y );
 
     # Ship out.
-    $pdf->saveas("pdfapi1.pdf");
+    $pdf->save;
 }
 
 ################ Subroutines ################
@@ -86,26 +98,13 @@ sub showlayout {
 }
 
 sub setup_fonts {
-    # Register all corefonts. Useful for fallback.
-    # Not required, skip if you have your own fonts.
     my $fd = Text::Layout::FontConfig->new;
-    # $fd->register_corefonts;
 
     # Add font dir and register fonts.
     $fd->add_fontdirs( $ENV{HOME}."/.fonts", "/usr/share/fonts/" );
-    $fd->register_font( "ITCGaramond-Light.ttf",       "Garamond"               );
-    $fd->register_font( "ITCGaramond-Bold.ttf",        "Garamond", "Bold"       );
-    $fd->register_font( "ITCGaramond-LightItalic.ttf", "Garamond", "Italic"     );
-    $fd->register_font( "ITCGaramond-BoldItalic.ttf",  "Garamond", "BoldItalic" );
-
-    # Make Serif alias for Garamond.
-    $fd->register_aliases( "Garamond", "Serif" );
-
-    # Add a Sans family.
-    $fd->register_font( "DejaVuSans.ttf",             "Sans"               );
-    $fd->register_font( "DejaVuSans-Bold.ttf",        "Sans", "Bold"       );
-    $fd->register_font( "DejaVuSans-Oblique.ttf",     "Sans", "Italic"     );
-    $fd->register_font( "DejaVuSans-BoldOblique.ttf", "Sans", "BoldItalic" );
+    for ( "", qw( Bold Italic BoldItalic ) ) {
+	$fd->register_font( "FreeSerif$_.ttf", "freeserif", $_ );
+    }
 }
 
 ################ Main entry point ################
@@ -113,13 +112,5 @@ sub setup_fonts {
 # Setup the fonts.
 setup_fonts();
 
-if ( 1 ) {
-    # For compliancy, use Pango units;
-    $layout->set_pango_scale;
-    $PANGO_SCALE = 1000;
-}
-else {
-    $PANGO_SCALE = 1;
-}
-
+# Run...
 main();
